<!DOCTYPE TS><TS>
<context>
    <name>AudioCart</name>
    <message>
        <source>Copying audio...</source>
        <translation>Kopiere Audio...</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>WT</source>
        <translation>WT</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>BESCHREIBUNG</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>LAST PLAYED</source>
        <translation>ZUL. GESPIELT</translation>
    </message>
    <message>
        <source># OF PLAYS</source>
        <translation># GESPIELT</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation>HERKUNFT</translation>
    </message>
    <message>
        <source>OUTCUE</source>
        <translation>OUTCUE</translation>
    </message>
    <message>
        <source>START DATE</source>
        <translation>STARTDATUM</translation>
    </message>
    <message>
        <source>END DATE</source>
        <translation>ENDDATUM</translation>
    </message>
    <message>
        <source>DAYPART START</source>
        <translation>TAGESTEIL START</translation>
    </message>
    <message>
        <source>DAYPART END</source>
        <translation>TAGESTEIL ENDE</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAME</translation>
    </message>
    <message>
        <source>Cuts</source>
        <translation type="obsolete">Cuts</translation>
    </message>
    <message>
        <source>Cut Info</source>
        <translation>Cut Info</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnahme</translation>
    </message>
    <message>
        <source>Edit
Audio</source>
        <translation>Audio
editieren</translation>
    </message>
    <message>
        <source>Edit
Markers</source>
        <translation>Marker
editieren</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Rip CD</source>
        <translation>CD rippen</translation>
    </message>
    <message>
        <source>Are you sure you want to delete</source>
        <translation>Sind sie sicher dies löschen zu wollen</translation>
    </message>
    <message>
        <source>Delete Cut</source>
        <translation>Cut löschen</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>RDCatch Event existiert nicht</translation>
    </message>
    <message>
        <source>This cut is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation type="obsolete">Dieser Cut wird in einem oder mehreren RDCatch-Events
verwendet! Trotzdem löschen?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Zwischenablage leeren</translation>
    </message>
    <message>
        <source>Deleting this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Diesen Cut zu löschen wird auch die Zwischenablage
leeren. Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Clipboard Empty</source>
        <translation>Zwischenablage leer</translation>
    </message>
    <message>
        <source>Clipboard is currently empty.</source>
        <translation>Zwischenablage ist momentan leer.</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Audio existiert</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Dies wird die derzeitige Aufnahme löschen.
Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>[new cart]</source>
        <translation>[neuer cart]</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>1 Cut</source>
        <translation type="obsolete">1 Cut</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation>RDLibrary</translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation type="obsolete">Kann die Audiodatei(en) nicht löschen!</translation>
    </message>
    <message>
        <source>No audio is present in the cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>One or more cuts are used in one or more RDCatch events!
Do you still want to delete?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete audio for cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No data copied - you must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must select a single cut!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ORD</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CdRipper</name>
    <message>
        <source>Artist:</source>
        <translation>Künstler:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Andere:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Cart</source>
        <translation>FreeDB-Werte auf Cart anwenden</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Tracks</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>ANDERE</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYP</translation>
    </message>
    <message>
        <source>&amp;Rip
Track</source>
        <translation>Track
&amp;Rippen</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalisieren</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Audio existiert</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Dies wird die derzeitige Aufnahme löschen.
Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Zwischenablage leeren</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Diesen Cut zu rippen wird auch die Zwischenablage
leeren. Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Kein Zugriff</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Kann die Datei nicht zum schreiben öffnen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Audio Track</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Datentrack</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Rip vollständig</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Rip vollständig!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Rip abgebrochen</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">Der Rip wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Rip fehlgeschlagen</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">Der Ripper hat einen Fehler bemerkt.
Bitte überprüfen sie ihre Ripperkonfiguration und versuchen sie es erneut.</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation>RDLibrary - Importfehler</translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation>RDLibrary - Ripperfehler</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation>Rippen
abbrechen</translation>
    </message>
    <message>
        <source>Rip Track</source>
        <translation>Titel rippen</translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DiskRipper</name>
    <message>
        <source>Rip Disk</source>
        <translation>CD Rippen</translation>
    </message>
    <message>
        <source>Artist:</source>
        <translation>Künstler:</translation>
    </message>
    <message>
        <source>Album:</source>
        <translation>Album:</translation>
    </message>
    <message>
        <source>Other:</source>
        <translation>Andere:</translation>
    </message>
    <message>
        <source>Apply FreeDB Values to Carts</source>
        <translation>FreeDB-Werte auf Carts anwenden</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Tracks</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>TRACK</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>OTHER</source>
        <translation>ANDERE</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYP</translation>
    </message>
    <message>
        <source>CUT</source>
        <translation>CUT</translation>
    </message>
    <message>
        <source>Disk Progress</source>
        <translation>Gesamtfortschritt</translation>
    </message>
    <message>
        <source>Track Progress</source>
        <translation>Titelfortschritt</translation>
    </message>
    <message>
        <source>Set
&amp;Cut</source>
        <translation type="obsolete">&amp;Cut
setzen</translation>
    </message>
    <message>
        <source>Set All
&amp;New Carts</source>
        <translation type="obsolete">Alle &amp;Neuen
Carts setzen</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalisieren</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Level:</translation>
    </message>
    <message>
        <source>dBFS</source>
        <translation>dBFS</translation>
    </message>
    <message>
        <source>Autotrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>Channels:</source>
        <translation>Kanäle:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chließen</translation>
    </message>
    <message>
        <source>Cut Conflict</source>
        <translation>Cut-Konflikt</translation>
    </message>
    <message>
        <source>That cut has already been assigned a track!</source>
        <translation>Dieser Cut ist bereits einem Titel zugewiesen worden!</translation>
    </message>
    <message>
        <source>Cut Exists</source>
        <translation>Cut existiert</translation>
    </message>
    <message>
        <source>A recording already exists.
Do you want to overwrite it?</source>
        <translation>Eine Aufnahme existiert bereits.
Wollen sie sie überschreiben?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Zwischenablage leeren</translation>
    </message>
    <message>
        <source>Ripping this cut will also empty the clipboard.
Do you still want to proceed?</source>
        <translation>Diesen Cut zu rippen wird auch die Zwischenablage
leeren. Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Library Error</source>
        <translation type="obsolete">Bibliotheksfehler</translation>
    </message>
    <message>
        <source>Insufficient free carts available in group!</source>
        <translation type="obsolete">Nicht genug freie Carts in der Gruppe!</translation>
    </message>
    <message>
        <source>Audio Track</source>
        <translation>Audio Track</translation>
    </message>
    <message>
        <source>Data Track</source>
        <translation>Datentrack</translation>
    </message>
    <message>
        <source>Rip Complete</source>
        <translation>Rip vollständig</translation>
    </message>
    <message>
        <source>Rip complete!</source>
        <translation>Rip vollständig!</translation>
    </message>
    <message>
        <source>Rip Aborted</source>
        <translation type="obsolete">Rip abgebrochen</translation>
    </message>
    <message>
        <source>The rip has been aborted.</source>
        <translation type="obsolete">Der Rip wurde abgebrochen.</translation>
    </message>
    <message>
        <source>Rip Failed</source>
        <translation type="obsolete">Rip fehlgeschlagen</translation>
    </message>
    <message>
        <source>The ripper encountered an error.
Please check your ripper configuration and try again.</source>
        <translation type="obsolete">Der Ripper hat einen Fehler bemerkt.
Bitte überprüfen sie ihre Ripperkonfiguration und versuchen sie es erneut.</translation>
    </message>
    <message>
        <source>Total Progress</source>
        <translation>Totalfortschritt</translation>
    </message>
    <message>
        <source>No Access</source>
        <translation type="obsolete">Kein Zugriff</translation>
    </message>
    <message>
        <source>Unable to open the file for writing!</source>
        <translation type="obsolete">Kann die Datei nicht zum schreiben öffnen!</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="obsolete">OK</translation>
    </message>
    <message>
        <source>&amp;Rip
Disc</source>
        <translation>CD
&amp;Rippen</translation>
    </message>
    <message>
        <source>RDLibrary - Importer Error</source>
        <translation>RDLibrary - Importfehler</translation>
    </message>
    <message>
        <source>RDLibrary - Ripper Error</source>
        <translation>RDLibrary - Ripperfehler</translation>
    </message>
    <message>
        <source>Abort
Rip</source>
        <translation>Rippen
abbrechen</translation>
    </message>
    <message>
        <source>Rip
Disk</source>
        <translation>CD
Rippen</translation>
    </message>
    <message>
        <source>Rip aborted!</source>
        <translation>Rip abgebrochen!</translation>
    </message>
    <message>
        <source>Ripper Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create temporary directory!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Cart
Per Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Single
Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set
&amp;Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[continued]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Modify
Cart Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear
Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate carts in group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to allocate cart in group</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditCart</name>
    <message>
        <source>Number:</source>
        <translation>Nummer:</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Average Length:</source>
        <translation>Durchschnittslänge:</translation>
    </message>
    <message>
        <source>Enforce Length</source>
        <translation>Länge erzwingen</translation>
    </message>
    <message>
        <source>Forced Length:</source>
        <translation>erzwungene Länge:</translation>
    </message>
    <message>
        <source>Preserve Pitch</source>
        <translation>Pitch schützen</translation>
    </message>
    <message>
        <source>&amp;Title:</source>
        <translation>&amp;Titel:</translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation>&amp;Startdatum:</translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation>&amp;Enddatum:</translation>
    </message>
    <message>
        <source>&amp;Artist:</source>
        <translation>&amp;Künstler:</translation>
    </message>
    <message>
        <source>&amp;Year Released:</source>
        <translation>&amp;Jahr des Erscheinens:</translation>
    </message>
    <message>
        <source>U&amp;sage:</source>
        <translation>&amp;Verwendung:</translation>
    </message>
    <message>
        <source>Scheduler Codes</source>
        <translation>Scheduler Codes</translation>
    </message>
    <message>
        <source>Al&amp;bum:</source>
        <translation>Al&amp;bum:</translation>
    </message>
    <message>
        <source>Re&amp;cord Label:</source>
        <translation>Aufnahmebezei&amp;chnung:</translation>
    </message>
    <message>
        <source>C&amp;lient:</source>
        <translation>&amp;Kunde:</translation>
    </message>
    <message>
        <source>A&amp;gency:</source>
        <translation>A&amp;gentur:</translation>
    </message>
    <message>
        <source>&amp;Publisher:</source>
        <translation>&amp;Herausgeber:</translation>
    </message>
    <message>
        <source>Compos&amp;er:</source>
        <translation>Kompon&amp;ist:</translation>
    </message>
    <message>
        <source>&amp;User Defined:</source>
        <translation>Ben&amp;utzerdefiniert:</translation>
    </message>
    <message>
        <source>Schedule Cuts:</source>
        <translation type="obsolete">Cuts einplanen:</translation>
    </message>
    <message>
        <source>Execute Asynchronously</source>
        <translation>asynchron ausführen</translation>
    </message>
    <message>
        <source>&amp;Edit
Script</source>
        <translation>Skript
&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>AUDIO</source>
        <translation>AUDIO</translation>
    </message>
    <message>
        <source>MACRO</source>
        <translation>MACRO</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>UNBEKANNT</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>Sequentially</source>
        <translation type="obsolete">Sequentiell</translation>
    </message>
    <message>
        <source>Randomly</source>
        <translation type="obsolete">Zufällig</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Missing Title</source>
        <translation>Fehlender Titel</translation>
    </message>
    <message>
        <source>You must provide at least a Cart Title!</source>
        <translation>Sie müssen zumindest einen CartTitel angeben!</translation>
    </message>
    <message>
        <source>Length Mismatch</source>
        <translation>Länge stimmt nicht überein</translation>
    </message>
    <message>
        <source>One or more cut lengths exceed the timescaling
limits of the system!  Do you still want to save?</source>
        <translation>Ein oder mehrere Cutlängen überschreiten die Zeit-
Limits des Systems! Wollen sie trotzdem speichern?</translation>
    </message>
    <message>
        <source>Duplicate Title</source>
        <translation>Doppelter Titel</translation>
    </message>
    <message>
        <source>The cart title must be unique!</source>
        <translation>Der Cart-Titel muss einzigartig sein!</translation>
    </message>
    <message>
        <source>&amp;Edit
Notes</source>
        <translation>Notizen
&amp;editieren</translation>
    </message>
    <message>
        <source>RDLibrary - Edit Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cond&amp;uctor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Song &amp;ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Beats per Minute:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Event Length for Now &amp;&amp; Next Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Specified Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>By Weight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schedule Cuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The following cut order values are assigned more than once</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Cut Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditMacro</name>
    <message>
        <source>Edit Macro</source>
        <translation>Makro editieren</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>EditNotes</name>
    <message>
        <source>Notes for cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>EditSchedulerCodes</name>
    <message>
        <source>Select Scheduler Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Assigned Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ASSIGN to Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMOVE from Carts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Abbrechen</translation>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Library Filter</source>
        <translation>Bibliotheksfilter</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Abbrechen</translation>
    </message>
    <message>
        <source>&amp;Filter:</source>
        <translation>&amp;Filter:</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished">Typ:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished">S&amp;chließen</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished">ALLE</translation>
    </message>
    <message>
        <source>Cart Data Dump (fixed width)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart Data Dump (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prepend Field Names</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MacroCart</name>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>LINE</source>
        <translation>ZEILE</translation>
    </message>
    <message>
        <source>COMMAND</source>
        <translation>KOMMANDO</translation>
    </message>
    <message>
        <source>Macros</source>
        <translation>Makros</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>editieren</translation>
    </message>
    <message>
        <source>Run
Line</source>
        <translation>Zeile
starten</translation>
    </message>
    <message>
        <source>Run
Cart</source>
        <translation>Cart
starten</translation>
    </message>
    <message>
        <source>--- End of cart ---</source>
        <translation>--- Ende des Carts ---</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Please Wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <source>rdlibrary : </source>
        <translation>rdlibrary : </translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann nicht verbinden</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>&amp;Suchen</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>Group:</source>
        <translation>Gruppe:</translation>
    </message>
    <message>
        <source>Scheduler Code:</source>
        <translation>Scheduler Code:</translation>
    </message>
    <message>
        <source>Show Audio Carts</source>
        <translation>Audio Carts anzeigen</translation>
    </message>
    <message>
        <source>Show Macro Carts</source>
        <translation>Makro-Carts anzeigen</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>CART</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation>LÄNGE</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>KÜNSTLER</translation>
    </message>
    <message>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <source>END</source>
        <translation>ENDE</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KUNDE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENTUR</translation>
    </message>
    <message>
        <source>USER DEFINED</source>
        <translation>BENUTZERDEFINIERT</translation>
    </message>
    <message>
        <source>CUTS</source>
        <translation>CUTS</translation>
    </message>
    <message>
        <source>LAST CUT PLAYED</source>
        <translation>LETZTER GESPIELTER CUT</translation>
    </message>
    <message>
        <source>PLAY ORDER</source>
        <translation type="obsolete">ABSPIELREIHENFOLGE</translation>
    </message>
    <message>
        <source>ENFORCE LENGTH</source>
        <translation>LÄNGE ERZWINGEN</translation>
    </message>
    <message>
        <source>PRESERVE PITCH</source>
        <translation>PITCH SCHÜTZEN</translation>
    </message>
    <message>
        <source>LENGTH DEVIATION</source>
        <translation>LÄNGENABWEICHUNG</translation>
    </message>
    <message>
        <source>OWNED BY</source>
        <translation>GEHÖRT</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Hinzufügen</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editieren</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <source>&amp;Rip
CD</source>
        <translation>CD
&amp;Rippen</translation>
    </message>
    <message>
        <source>Re&amp;ports</source>
        <translation>Re&amp;porte</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chließen</translation>
    </message>
    <message>
        <source>ALL</source>
        <translation>ALLE</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Are you sure you want to delete cart(s)</source>
        <translation>Sind sie sicher diese(n) Cart(s)  löschen zu wollen</translation>
    </message>
    <message>
        <source>Delete Cart(s)</source>
        <translation>Cart(s)  löschen</translation>
    </message>
    <message>
        <source>Cart %06u is used in one or more RDCatch events!
Do you still want to delete it?</source>
        <translation>Cart %06u wird von einem oder mehreren RDCatch-Events
verwendet. Trotzdem löschen?</translation>
    </message>
    <message>
        <source>RDCatch Event Exists</source>
        <translation>RDCatch-Event existiert</translation>
    </message>
    <message>
        <source>Deleting cart %06u will also empty the clipboard.
      <byte value="x9"/>Do you still want to proceed?</source>
        <translation>Den Cart %06u zu löschen wird auch die Zwischenablage leeren
      <byte value="x9"/>Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Zwischenablage leeren</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation type="obsolete">Sequenz</translation>
    </message>
    <message>
        <source>Random</source>
        <translation type="obsolete">Zufall</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation>TFN</translation>
    </message>
    <message>
        <source>RDLibrary - Host:</source>
        <translation type="obsolete">RDLibrary-Host : </translation>
    </message>
    <message>
        <source>, User:</source>
        <translation type="obsolete">, Benutzer:</translation>
    </message>
    <message>
        <source>Show Note Bubbles</source>
        <translation>Zeige Notizen</translation>
    </message>
    <message>
        <source>RDLibrary</source>
        <translation>RDLibrary</translation>
    </message>
    <message>
        <source>Unable to delete audio!</source>
        <translation>Kann die Audiodatei(en) nicht löschen!</translation>
    </message>
    <message>
        <source>Show Only First </source>
        <translation>Zeige nur erste</translation>
    </message>
    <message>
        <source> Matches</source>
        <translation>Treffer</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COMPOSER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CONDUCTOR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PUBLISHER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow Cart Dragging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command-line option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALBUM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecordCut</name>
    <message>
        <source>RDLibrary - Record</source>
        <translation>RDLibrary - Aufnahme</translation>
    </message>
    <message>
        <source>&amp;Description</source>
        <translation>&amp;BESCHREIBUNG</translation>
    </message>
    <message>
        <source>&amp;Outcue</source>
        <translation>&amp;OUTCUE</translation>
    </message>
    <message>
        <source>Origin</source>
        <translation>HERKUNFT</translation>
    </message>
    <message>
        <source>ISRC</source>
        <translation>ISRC</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Gewichtung</translation>
    </message>
    <message>
        <source>Last Played</source>
        <translation>ZUL. GESPIELT</translation>
    </message>
    <message>
        <source># of Plays</source>
        <translation># GESPIELT</translation>
    </message>
    <message>
        <source>Cut is EVERGREEN</source>
        <translation>Cut ist EVERGREEN</translation>
    </message>
    <message>
        <source>Air Date/Time</source>
        <translation>Sendezeit/-Datum</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktiviert</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>deaktiviert</translation>
    </message>
    <message>
        <source>&amp;Start</source>
        <translation>&amp;START</translation>
    </message>
    <message>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <source>Daypart</source>
        <translation>Tageszeit</translation>
    </message>
    <message>
        <source>&amp;Start Time</source>
        <translation>&amp;Startzeit</translation>
    </message>
    <message>
        <source>End Time</source>
        <translation>Endzeit</translation>
    </message>
    <message>
        <source>Day of the Week</source>
        <translation>Wochentag</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>Set All</source>
        <translation>Alle Setzen</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Alle Löschen</translation>
    </message>
    <message>
        <source>NO SYNC!</source>
        <translation type="obsolete">KEINE SYNCHRONISIERUNG!</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <source>Record Mode</source>
        <translation>Aufnahmemodus</translation>
    </message>
    <message>
        <source>AutoTrim</source>
        <translation>Autotrim</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>S&amp;chließen</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>VOX</source>
        <translation>VOX</translation>
    </message>
    <message>
        <source>On</source>
        <translation>An</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <source>Audio Exists</source>
        <translation>Audio existiert</translation>
    </message>
    <message>
        <source>This will overwrite the existing recording.
Do you want to proceed?</source>
        <translation>Dies wird die derzeitige Aufnahme löschen.
Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Empty Clipboard</source>
        <translation>Zwischenablage leeren</translation>
    </message>
    <message>
        <source>This will empty the clipboard.
Do you still want to proceed?</source>
        <translation>Dies wird die Zwischenablage
leeren. Trotzdem fortfahren?</translation>
    </message>
    <message>
        <source>Missing Description</source>
        <translation>Fehlende Beschreibung</translation>
    </message>
    <message>
        <source>You must provide a Cut Description!</source>
        <translation>Sie müssen zumindest eine Cut-Beschreibung angeben!</translation>
    </message>
    <message>
        <source>Invalid ISRC</source>
        <translation>Ungültiges ISRC</translation>
    </message>
    <message>
        <source>The ISRC data is malformed or invalid!</source>
        <translation>Die ISRC-Daten sind ungültig!</translation>
    </message>
    <message>
        <source>Invalid Date</source>
        <translation>Ungültiges Datum</translation>
    </message>
    <message>
        <source>The Start Date is invalid!</source>
        <translation>Das Startdatum ist ungültig!</translation>
    </message>
    <message>
        <source>The End Date is invalid!</source>
        <translation>Das Enddatum ist ungültig!</translation>
    </message>
    <message>
        <source>The End Date is prior to the Start Date!</source>
        <translation>Das End- liegt vor dem Start-Datum!</translation>
    </message>
    <message>
        <source>The End Date has already passed!
Do you still want to save?</source>
        <translation>Das Enddatum ist bereits vergangen!
Trotzdem speichern?</translation>
    </message>
    <message>
        <source>Invalid Time</source>
        <translation>Ungültige Zeit</translation>
    </message>
    <message>
        <source>The Start Time is invalid!</source>
        <translation>Die Startzeit ist ungültig!</translation>
    </message>
    <message>
        <source>The End Time is invalid!</source>
        <translation>Die Endzeit ist ungültig!</translation>
    </message>
    <message>
        <source>The StartTime cannot be the same as the End Time!</source>
        <translation>Die Start- und End-Zeit können nicht gleich sein!</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann nicht verbinden</translation>
    </message>
    <message>
        <source>Unable to connect to Core AudioEngine</source>
        <translation>Kann nicht zur CoreAudioEngine verbinden</translation>
    </message>
    <message>
        <source>&amp;ISCI Code</source>
        <translation>&amp;ISCI Code</translation>
    </message>
    <message>
        <source>AES ALARM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Order</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
